#   Copyright (c) 2018 The Regents of the University of California,
#   through Lawrence Berkeley National Laboratory.  
#
#   Author: David Williams-Young
#   
#   This file is part of PEXSI. All rights reserved.
#   
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions are met:
#   
#   (1) Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#   (2) Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#   (3) Neither the name of the University of California, Lawrence Berkeley
#   National Laboratory, U.S. Dept. of Energy nor the names of its contributors may
#   be used to endorse or promote products derived from this software without
#   specific prior written permission.
#   
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
#   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
#   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
#   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
#   ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
#   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
#   ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#   
#   You are under no obligation whatsoever to provide any bug fixes, patches, or
#   upgrades to the features, functionality or performance of the source code
#   ("Enhancements") to anyone; however, if you choose to make your Enhancements
#   available either publicly, or directly to Lawrence Berkeley National
#   Laboratory, without imposing a separate written license agreement for such
#   Enhancements, then you hereby grant the following license: a non-exclusive,
#   royalty-free perpetual license to install, use, modify, prepare derivative
#   works, incorporate into other computer software, distribute, and sublicense
#   such enhancements or derivative works thereof, in binary and source code form.
#
cmake_minimum_required( VERSION 3.10 ) # Require CMake 3.10+

get_filename_component(PEXSI_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)
include(CMakeFindDependencyMacro)

list(APPEND CMAKE_MODULE_PATH ${PEXSI_CMAKE_DIR})
list(APPEND CMAKE_MODULE_PATH ${PEXSI_CMAKE_DIR}/modules)

set( PEXSI_ENABLE_PROFILE OFF )
set( PEXSI_ENABLE_SYMPACK  )
set( PEXSI_ENABLE_OPENMP  ON  )

find_dependency( MPI )
if( PEXSI_ENABLE_OPENMP )
  find_dependency( OpenMP )
endif()

set( BLAS_LIBRARIES       "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/libblas.dylib"       CACHE STRING "BLAS Libraries"       FORCE )
set( LAPACK_LIBRARIES       "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/liblapack.dylib"       CACHE STRING "LAPACK Libraries"       FORCE )
set( ParMETIS_LIBRARIES     "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/libparmetis.dylib;METIS::METIS;MPI::MPI_C"     CACHE STRING "ParMETIS Libraries"     FORCE )
set( METIS_LIBRARIES        "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/libmetis.dylib"        CACHE STRING "METIS Libraries"        FORCE )
set( SuperLU_DIST_LIBRARIES "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/libsuperlu_dist.dylib;BLAS::BLAS;ParMETIS::ParMETIS" CACHE STRING "SuperLU_DIST Libraries" FORCE )
set( ParMETIS_INCLUDE_DIR     "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/include"     CACHE STRING "ParMETIS Libraries"     FORCE )
set( METIS_INCLUDE_DIR        "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/include"        CACHE STRING "METIS Libraries"        FORCE )
set( SuperLU_DIST_INCLUDE_DIR "/Users/runner/miniforge3/conda-bld/pexsi_1647180427346/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/include" CACHE STRING "SuperLU_DIST Libraries" FORCE )

find_dependency( LAPACK )
find_dependency( SuperLU_DIST )

list(REMOVE_AT CMAKE_MODULE_PATH -1)

if(NOT TARGET PEXSI::PEXSI)
    include("${PEXSI_CMAKE_DIR}/PEXSITargets.cmake")
endif()

set(PEXSI_LIBRARIES PEXSI::PEXSI)
